Documentation
¶
Overview ¶
Package v1alpha1 contains API Schema definitions for the camptocamp v1alpha1 API group +k8s:deepcopy-gen=package,register +groupName=camptocamp.com
Package v1alpha1 contains API Schema definitions for the camptocamp v1alpha1 API group +k8s:deepcopy-gen=package,register +groupName=camptocamp.com
Index ¶
Constants ¶
This section is empty.
Variables ¶
var ( // SchemeGroupVersion is group version used to register these objects SchemeGroupVersion = schema.GroupVersion{Group: "camptocamp.com", Version: "v1alpha1"} // SchemeBuilder is used to add go types to the GroupVersionKind scheme SchemeBuilder = &scheme.Builder{GroupVersion: SchemeGroupVersion} )
Functions ¶
func GetOpenAPIDefinitions ¶
func GetOpenAPIDefinitions(ref common.ReferenceCallback) map[string]common.OpenAPIDefinition
Types ¶
type Varnish ¶
type Varnish struct {
metav1.TypeMeta `json:",inline"`
metav1.ObjectMeta `json:"metadata,omitempty"`
Spec VarnishSpec `json:"spec,omitempty"`
Status VarnishStatus `json:"status,omitempty"`
}
Varnish is the Schema for the varnishes API +k8s:openapi-gen=true +kubebuilder:subresource:status
func (*Varnish) DeepCopy ¶
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new Varnish.
func (*Varnish) DeepCopyInto ¶
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*Varnish) DeepCopyObject ¶
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type VarnishList ¶
type VarnishList struct {
metav1.TypeMeta `json:",inline"`
metav1.ListMeta `json:"metadata,omitempty"`
Items []Varnish `json:"items"`
}
VarnishList contains a list of Varnish
func (*VarnishList) DeepCopy ¶
func (in *VarnishList) DeepCopy() *VarnishList
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new VarnishList.
func (*VarnishList) DeepCopyInto ¶
func (in *VarnishList) DeepCopyInto(out *VarnishList)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*VarnishList) DeepCopyObject ¶
func (in *VarnishList) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type VarnishSpec ¶
type VarnishSpec struct {
}
VarnishSpec defines the desired state of Varnish +k8s:openapi-gen=true
func (*VarnishSpec) DeepCopy ¶
func (in *VarnishSpec) DeepCopy() *VarnishSpec
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new VarnishSpec.
func (*VarnishSpec) DeepCopyInto ¶
func (in *VarnishSpec) DeepCopyInto(out *VarnishSpec)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type VarnishStatus ¶
type VarnishStatus struct {
}
VarnishStatus defines the observed state of Varnish +k8s:openapi-gen=true
func (*VarnishStatus) DeepCopy ¶
func (in *VarnishStatus) DeepCopy() *VarnishStatus
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new VarnishStatus.
func (*VarnishStatus) DeepCopyInto ¶
func (in *VarnishStatus) DeepCopyInto(out *VarnishStatus)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.